'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var lodash = require('lodash');
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));
var styledSystem = require('styled-system');
var polished = require('polished');
var reactAnimations = require('react-animations');

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    var ownKeys = Object.keys(source);

    if (typeof Object.getOwnPropertySymbols === 'function') {
      ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
      }));
    }

    ownKeys.forEach(function (key) {
      _defineProperty(target, key, source[key]);
    });
  }

  return target;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _taggedTemplateLiteral(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _iterableToArray(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n    ", "\n    ", "\n  "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
var getFromTheme = function getFromTheme(theme, lookup, fallback) {
  return lodash.get(theme, lookup, fallback);
};
var getComponentVariant = function getComponentVariant(theme, key, variant) {
  var config = getFromTheme(theme, "components.".concat(key, ".variants.").concat(variant), theme.variants[variant]);
  if (!config) throw new Error("Refractal: \"".concat(variant, "\" variant not found in theme..."));
  return config;
};
var getComponentStyle = function getComponentStyle(key) {
  return function (_ref) {
    var theme = _ref.theme;
    return getFromTheme(theme, "components.".concat(key, ".style"), {});
  };
};
var getComponentClassName = function getComponentClassName(name) {
  return function (_ref2) {
    var classPrefix = _ref2.theme.classPrefix,
        variant = _ref2.variant;
    return "".concat(classPrefix, "-").concat(name, " ").concat(variant ? "".concat(classPrefix, "-").concat(name, "-").concat(variant) : '').trim();
  };
};
var createComponent = function createComponent(_ref3) {
  var name = _ref3.name,
      _ref3$tag = _ref3.tag,
      tag = _ref3$tag === void 0 ? 'div' : _ref3$tag,
      as = _ref3.as,
      _ref3$attrs = _ref3.attrs,
      attrs = _ref3$attrs === void 0 ? {} : _ref3$attrs;
  var component = as ? styled__default(as) : styled__default[tag];
  return component.attrs(_objectSpread({
    className: getComponentClassName(lodash.kebabCase(name))
  }, attrs))(_templateObject(), getComponentStyle(name), function (_ref4) {
    var _ref4$styles = _ref4.styles,
        styles = _ref4$styles === void 0 ? {} : _ref4$styles;
    return styles[name] || {};
  });
};

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n      padding: 1rem;\n      margin-bottom: 1rem;\n      border: 0;\n      font-size: 14px;\n      font-family: ", ";\n      border-radius: ", "px;\n      background: ", ";\n      color: ", ";\n\n      a {\n        color: inherit;\n        text-decoration: underline;\n      }\n    "]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1() {
  var data = _taggedTemplateLiteral(["\n  ", ";\n\n  ", ";\n"]);

  _templateObject$1 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledAlert = createComponent({
  name: 'Alert'
}).extend(_templateObject$1(), function (_ref) {
  var variant = _ref.variant,
      theme = _ref.theme;

  var _getComponentVariant = getComponentVariant(theme, 'Alert', variant),
      backgroundColor = _getComponentVariant.backgroundColor,
      fontColor = _getComponentVariant.fontColor;

  return styled.css(_templateObject2(), theme.typography.fontFamily || 'inherit', theme.elementRadius, backgroundColor, fontColor);
}, styledSystem.space);

var Alert = function Alert(props) {
  return React__default.createElement(StyledAlert, props);
};

Alert.propTypes = {
  variant: PropTypes.string
};
Alert.defaultProps = {
  variant: 'primary'
};

function _templateObject$2() {
  var data = _taggedTemplateLiteral(["\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n  ", "\n"]);

  _templateObject$2 = function _templateObject() {
    return data;
  };

  return data;
}
var Box = createComponent({
  name: 'Box'
}).extend(_templateObject$2(), styledSystem.display, styledSystem.space, styledSystem.color, styledSystem.fontSize, styledSystem.fontWeight, styledSystem.textAlign, styledSystem.lineHeight, styledSystem.height, styledSystem.width, styledSystem.flex, styledSystem.alignSelf, styledSystem.justifySelf);
Box.propTypes = _objectSpread({}, styledSystem.display.propTypes, styledSystem.space.propTypes, styledSystem.color.propTypes, styledSystem.width.propTypes, styledSystem.fontSize.propTypes, styledSystem.fontWeight.propTypes, styledSystem.textAlign.propTypes, styledSystem.lineHeight.propTypes, styledSystem.flex.propTypes, styledSystem.alignSelf.propTypes, styledSystem.justifySelf.propTypes);

function _templateObject5() {
  var data = _taggedTemplateLiteral(["\n  & > *:not(:first-child) {\n    margin-left: 1rem;\n  }\n"]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4() {
  var data = _taggedTemplateLiteral(["\n      font-family: inherit;\n      display: inline-block;\n      text-align: center;\n      cursor: pointer;\n      text-transform: capitalize;\n      font-weight: bold;\n      text-decoration: none;\n      appearance: none;\n      border-radius: ", "px;\n      pointer-events: ", ";\n      opacity: ", ";\n      color: ", ";\n      height: ", "px;\n      padding: 0 ", "px;\n      font-size: ", "px;\n      width: ", ";\n      background: ", ";\n      border: ", ";\n      transition: 175ms;\n\n      ", ";\n      ", ";\n\n      &:hover {\n        background: ", ";\n        border-color: ", ";\n      }\n\n      &:active {\n        background: ", ";\n        border-color: ", ";\n      }\n    "]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteral(["\n  ", ";\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$1() {
  var data = _taggedTemplateLiteral(["\n  color: transparent !important;\n  pointer-events: none;\n  position: relative;\n  text-index: -9999px;\n  opacity: 0.75;\n\n  &::after {\n    display: block;\n    content: '';\n    border-color: ", ";\n    animation: ", " 820ms infinite linear;\n    border-width: ", "px;\n    border-style: solid;\n    border-radius: 100%;\n    border-right-color: transparent;\n    border-top-color: transparent;\n    height: ", "px;\n    left: 50%;\n    margin-left: -", "px;\n    margin-top: -", "px;\n    position: absolute;\n    top: 48%;\n    width: ", "px;\n  }\n"]);

  _templateObject2$1 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$3() {
  var data = _taggedTemplateLiteral(["\n  from {\n    transform: rotate(0deg);\n  }\n\n  to {\n    transform: rotate(360deg);\n}"]);

  _templateObject$3 = function _templateObject() {
    return data;
  };

  return data;
}
var spinKeyframes = styled.keyframes(_templateObject$3());

var loadingCss = function loadingCss(_ref) {
  var height = _ref.height,
      fontColor = _ref.fontColor;
  return styled.css(_templateObject2$1(), fontColor, spinKeyframes, height / 12, height / 2, height / 4, height / 4, height / 2);
};

var StyledButton = createComponent({
  name: 'Button',
  tag: 'button'
}).extend(_templateObject3(), function (_ref2) {
  var variant = _ref2.variant,
      size = _ref2.size,
      theme = _ref2.theme,
      _ref2$outline = _ref2.outline,
      outline = _ref2$outline === void 0 ? false : _ref2$outline,
      _ref2$block = _ref2.block,
      block = _ref2$block === void 0 ? false : _ref2$block,
      _ref2$disabled = _ref2.disabled,
      disabled = _ref2$disabled === void 0 ? false : _ref2$disabled,
      _ref2$loading = _ref2.loading,
      loading = _ref2$loading === void 0 ? false : _ref2$loading,
      _ref2$transparent = _ref2.transparent,
      transparent = _ref2$transparent === void 0 ? false : _ref2$transparent,
      _ref2$height = _ref2.height,
      height = _ref2$height === void 0 ? theme.heights[size] : _ref2$height,
      _ref2$fontSize = _ref2.fontSize,
      fontSize = _ref2$fontSize === void 0 ? theme.fontSizes[size] : _ref2$fontSize,
      _ref2$borderRadius = _ref2.borderRadius,
      borderRadius = _ref2$borderRadius === void 0 ? theme.radius || 2 : _ref2$borderRadius;

  var _getComponentVariant = getComponentVariant(theme, 'Button', variant),
      backgroundColor = _getComponentVariant.backgroundColor,
      fontColor = _getComponentVariant.fontColor;

  return styled.css(_templateObject4(), borderRadius, disabled ? 'none' : 'auto', disabled ? '0.65' : '1', fontColor, height, height / 2, fontSize, block ? '100%' : 'auto', outline || transparent ? 'transparent' : backgroundColor, transparent ? 'none' : "1px solid ".concat(outline ? fontColor : polished.darken(0.05, backgroundColor)), loading ? loadingCss({
    height: height,
    fontColor: fontColor
  }) : '', styledSystem.space, polished.darken(0.05, backgroundColor), polished.darken(0.05, backgroundColor), polished.darken(0.075, backgroundColor), polished.darken(0.075, backgroundColor));
});

var Button = function Button(props) {
  return React__default.createElement(StyledButton, props);
};

Button.propTypes = {
  variant: PropTypes.string,
  size: PropTypes.string,
  outline: PropTypes.bool,
  block: PropTypes.bool,
  disabled: PropTypes.bool,
  loading: PropTypes.bool,
  transparent: PropTypes.bool
};
Button.defaultProps = {
  variant: 'primary',
  size: 'md',
  outline: false,
  block: false,
  disabled: false,
  loading: false,
  transparent: false
};
Button.Group = createComponent({
  name: 'ButtonGroup'
}).extend(_templateObject5());

function _templateObject4$1() {
  var data = _taggedTemplateLiteral(["\n  padding: 1rem;\n  border-top: 1px solid ", ";\n\n  ", ";\n"]);

  _templateObject4$1 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$1() {
  var data = _taggedTemplateLiteral(["\n  padding: 1rem;\n\n  ", ";\n"]);

  _templateObject3$1 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$2() {
  var data = _taggedTemplateLiteral(["\n  padding: 1rem;\n  border-bottom: 1px solid ", ";\n\n  ", ";\n"]);

  _templateObject2$2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$4() {
  var data = _taggedTemplateLiteral(["\n  background: white;\n  box-shadow: ", ";\n\n  ", ";\n  ", ";\n"]);

  _templateObject$4 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledCard = createComponent({
  name: 'Card'
}).extend(_templateObject$4(), function (p) {
  return p.shadow ? styledSystem.themeGet('shadow', '0 4px 10px rgba(0, 29, 54, 0.04), 0 -2px 6px rgba(0, 29, 54, 0.025);') : 'none';
}, styledSystem.borderRadius, styledSystem.space);

var Card = function Card(props) {
  return React__default.createElement(StyledCard, props);
};

Card.propTypes = {
  shadow: PropTypes.bool
};
Card.defaultProps = {
  shadow: true
};
Card.Header = createComponent({
  name: 'CardHeader'
}).extend(_templateObject2$2(), styledSystem.themeGet('colors.grayLight'), styledSystem.space);
Card.Body = createComponent({
  name: 'CardBody'
}).extend(_templateObject3$1(), styledSystem.space);
Card.Footer = createComponent({
  name: 'CardFooter'
}).extend(_templateObject4$1(), styledSystem.themeGet('colors.grayLight'), styledSystem.space);

function _templateObject3$2() {
  var data = _taggedTemplateLiteral(["\n          pointer-events: none;\n          opacity: 0.65;\n        "]);

  _templateObject3$2 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$3() {
  var data = _taggedTemplateLiteral(["\n      color: ", ";\n      ", ";\n    "]);

  _templateObject2$3 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$5() {
  var data = _taggedTemplateLiteral(["\n  ", "\n"]);

  _templateObject$5 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledIcon = createComponent({
  name: 'Icon',
  tag: 'i'
}).extend(_templateObject$5(), function (p) {
  var colorFromTheme = p.theme.colors[p.color];
  var color = p.checked ? colorFromTheme || p.color : p.theme.colors.grayMid;
  return styled.css(_templateObject2$3(), color, p.disabled && styled.css(_templateObject3$2()));
});

var Icon =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Icon, _React$Component);

  function Icon(props) {
    var _this;

    _classCallCheck(this, Icon);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Icon).call(this, props));

    if (!_this.constructor.injected) {
      var link = document.createElement('link');
      link.rel = 'stylesheet';
      link.type = 'text/css';
      link.href = _this.constructor.iconUrl;
      document.head.appendChild(link);
      _this.constructor.injected = true;
    }

    return _this;
  }

  _createClass(Icon, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          name = _this$props.name,
          size = _this$props.size,
          color = _this$props.color,
          _this$props$style = _this$props.style,
          style = _this$props$style === void 0 ? {} : _this$props$style,
          _this$props$className = _this$props.className,
          className = _this$props$className === void 0 ? '' : _this$props$className;
      var iconPrefix = this.constructor.iconPrefix;
      return React__default.createElement(StyledIcon, _extends({}, this.props, {
        className: "".concat(iconPrefix, " ").concat(iconPrefix, "-").concat(name, " ").concat(className),
        style: _objectSpread({
          fontSize: size,
          color: color || 'inherit'
        }, style)
      }));
    }
  }]);

  return Icon;
}(React__default.Component);

_defineProperty(Icon, "injected", false);

_defineProperty(Icon, "iconUrl", 'https://cdn.heydoctor.co/assets/css/material-design-icons.css');

_defineProperty(Icon, "iconPrefix", 'mdi');

Icon.propTypes = {
  name: PropTypes.string.isRequired,
  size: PropTypes.number,
  color: PropTypes.string
};

function _templateObject$6() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  margin: 4px 0 0 4px;\n  color: ", ";\n  font-size: 10px;\n"]);

  _templateObject$6 = function _templateObject() {
    return data;
  };

  return data;
}
var FormError = createComponent({
  name: 'FormError',
  tag: 'span'
}).extend(_templateObject$6(), function (p) {
  return p.theme.colors.red;
});

var Flex = createComponent({
  name: 'Flex',
  as: Box
}).extend({
  display: 'flex'
}, styledSystem.flexWrap, styledSystem.flexDirection, styledSystem.alignItems, styledSystem.alignSelf, styledSystem.justifyContent);
Flex.displayName = 'Flex';
Flex.propTypes = _objectSpread({}, styledSystem.flexWrap.propTypes, styledSystem.flexDirection.propTypes, styledSystem.alignItems.propTypes, styledSystem.alignSelf.propTypes, styledSystem.justifyContent.propTypes);

function _templateObject3$3() {
  var data = _taggedTemplateLiteral(["\n  margin-left: 8px;\n  font-size: ", "px;\n"]);

  _templateObject3$3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$4() {
  var data = _taggedTemplateLiteral(["\n  display: none;\n  pointer-events: ", ";\n"]);

  _templateObject2$4 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$7() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  margin-bottom: 0;\n  cursor: pointer;\n\n  & + & {\n    margin-left: ", ";\n    margin-top: ", ";\n  }\n"]);

  _templateObject$7 = function _templateObject() {
    return data;
  };

  return data;
}
var CheckboxContainer = createComponent({
  name: 'Checkbox',
  tag: 'label'
}).extend(_templateObject$7(), function (p) {
  return p.horizontal ? '12px' : 0;
}, function (p) {
  return p.horizontal ? 0 : '4px';
});
var StyledInput = createComponent({
  name: 'CheckboxInput',
  tag: 'input'
}).extend(_templateObject2$4(), function (p) {
  return p.disabled ? 'none' : 'auto';
});
var StyledIcon$1 = createComponent({
  name: 'CheckboxIcon',
  as: Icon
});
var StyledLabel = createComponent({
  name: 'CheckboxLabel',
  as: Flex
}).extend(_templateObject3$3(), function (p) {
  return p.fontSize;
});

var Checkbox =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Checkbox, _React$Component);

  function Checkbox() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Checkbox);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Checkbox)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      value: _this.props.value
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleChange", function () {
      var _this$props = _this.props,
          valueTrue = _this$props.valueTrue,
          valueFalse = _this$props.valueFalse,
          onChange = _this$props.onChange;
      var newValue = _this.checked ? valueFalse : valueTrue;

      _this.setState({
        value: newValue
      }, function () {
        onChange(_this.props.name, newValue);
      });
    });

    return _this;
  }

  _createClass(Checkbox, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      if (this.props.value !== undefined && this.state.value !== this.props.value) {
        this.setState({
          value: this.props.value
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          label = _this$props2.label,
          id = _this$props2.id,
          error = _this$props2.error,
          name = _this$props2.name,
          fontSize = _this$props2.fontSize,
          iconOn = _this$props2.iconOn,
          iconOff = _this$props2.iconOff,
          iconSize = _this$props2.iconSize,
          color = _this$props2.color,
          horizontal = _this$props2.horizontal,
          disabled = _this$props2.disabled;
      var checked = this.checked;
      return React__default.createElement(CheckboxContainer, {
        horizontal: horizontal
      }, React__default.createElement(StyledInput, {
        id: id,
        name: name,
        type: "checkbox",
        checked: checked,
        disabled: disabled,
        onChange: this.handleChange
      }), React__default.createElement(Flex, {
        alignItems: "center"
      }, React__default.createElement(StyledIcon$1, {
        size: iconSize,
        color: color,
        checked: checked,
        name: checked ? iconOn : iconOff
      }), label && React__default.createElement(StyledLabel, {
        fontSize: fontSize
      }, label)), !this.state.focused && error ? React__default.createElement(FormError, null, lodash.capitalize(error)) : null);
    }
  }, {
    key: "checked",
    get: function get() {
      return this.state.value === this.props.valueTrue;
    }
  }]);

  return Checkbox;
}(React__default.Component);

_defineProperty(Checkbox, "propTypes", {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.bool]),
  valueTrue: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.bool]),
  valueFalse: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.bool]),
  onChange: PropTypes.func,
  iconOn: PropTypes.string,
  iconOff: PropTypes.string,
  iconSize: PropTypes.number,
  fontSize: PropTypes.number,
  color: PropTypes.string,
  horizontal: PropTypes.bool,
  disabled: PropTypes.bool
});

_defineProperty(Checkbox, "defaultProps", {
  color: 'primary',
  iconOn: 'checkbox-marked',
  iconOff: 'checkbox-blank-outline',
  valueTrue: true,
  valueFalse: false,
  iconSize: 18,
  horizontal: false,
  onChange: function onChange() {},
  disabled: false
});

var CheckboxGroup =
/*#__PURE__*/
function (_Component) {
  _inherits(CheckboxGroup, _Component);

  function CheckboxGroup() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, CheckboxGroup);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(CheckboxGroup)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      selected: Array.isArray(_this.props.value) ? _toConsumableArray(_this.props.value) : []
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "createChangeHandler", function (choice) {
      return function (name, value) {
        var selected = _this.state.selected;
        var newSelected;

        if (!selected.includes(value)) {
          if (choice.exclusive) {
            newSelected = [value];
          } else {
            newSelected = _this.props.choices.filter(function (c) {
              return !c.exclusive && (c.value === value || selected.includes(c.value));
            }).map(function (c) {
              return c.value;
            });
          }
        } else {
          var index = selected.indexOf(value);
          newSelected = _toConsumableArray(selected.slice(0, index)).concat(_toConsumableArray(selected.slice(index + 1)));
        }

        _this.setState({
          selected: newSelected
        }, function () {
          _this.props.onChange(_this.props.name, newSelected);
        });
      };
    });

    return _this;
  }

  _createClass(CheckboxGroup, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          name = _this$props.name,
          color = _this$props.color,
          choices = _this$props.choices,
          error = _this$props.error,
          horizontal = _this$props.horizontal;
      var selected = this.state.selected;
      return React__default.createElement(Box, null, React__default.createElement(Flex, {
        flexDirection: horizontal ? 'row' : 'column'
      }, choices.length && choices.map(function (choice) {
        var _choice$value = choice.value,
            value = _choice$value === void 0 ? choice.id : _choice$value;
        var key = "checkbox-".concat(name, "-").concat(value);
        return React__default.createElement(Checkbox, {
          key: key,
          id: key,
          name: key,
          label: choice.label,
          color: color,
          horizontal: horizontal,
          value: selected && selected.includes(value) ? value : null,
          valueTrue: value,
          valueFalse: value,
          onChange: _this2.createChangeHandler(choice)
        });
      })), !!error && React__default.createElement(FormError, null, error));
    }
  }]);

  return CheckboxGroup;
}(React.Component);

_defineProperty(CheckboxGroup, "propTypes", {
  name: PropTypes.string.isRequired,
  color: PropTypes.string,
  horizontal: PropTypes.bool,
  value: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])),
  choices: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    label: PropTypes.string,
    disabled: PropTypes.bool
  })).isRequired,
  onChange: PropTypes.func
});

_defineProperty(CheckboxGroup, "defaultProps", {
  color: 'primary',
  horizontal: false,
  onChange: function onChange() {}
});

function _templateObject7() {
  var data = _taggedTemplateLiteral(["\n      order: ", ";\n      ", ";\n    "]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteral(["\n              @media (min-width: ", "px) {\n                ", ";\n                ", ";\n              }\n            "]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$1() {
  var data = _taggedTemplateLiteral(["\n              ", ";\n              ", ";\n            "]);

  _templateObject5$1 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$2() {
  var data = _taggedTemplateLiteral(["\n  box-sizing: border-box;\n  flex: 1 0 auto;\n  flex-direction: column;\n  padding-left: ", "px;\n  padding-right: ", "px;\n\n  ", "\n"]);

  _templateObject4$2 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$4() {
  var data = _taggedTemplateLiteral(["\n  margin-left: ", ";\n"]);

  _templateObject3$4 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$5() {
  var data = _taggedTemplateLiteral(["\n        max-width: 100%;\n        width: 100%;\n        flex: auto;\n      "]);

  _templateObject2$5 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$8() {
  var data = _taggedTemplateLiteral(["\n        display: block;\n        flex-basis: ", ";\n        max-width: ", ";\n      "]);

  _templateObject$8 = function _templateObject() {
    return data;
  };

  return data;
}

var getWidthPercent = function getWidthPercent(width, columns) {
  return "".concat(width / columns * 100, "%");
};

var getColumnWidth = function getColumnWidth(width, columns) {
  return width / columns !== 1 ? styled.css(_templateObject$8(), getWidthPercent(width, columns), getWidthPercent(width, columns)) : styled.css(_templateObject2$5());
};

var getPadding = function getPadding(p) {
  if (p.collapse) return 0;
  return p.gutter ? p.gutter / 2 : p.theme.grid.gutter / 2;
};

var getOffset = function getOffset(offset, columns) {
  return styled.css(_templateObject3$4(), offset === 0 ? 0 : getWidthPercent(offset, columns));
};

var StyledColumn = createComponent({
  name: 'Column',
  as: Flex
}).extend(_templateObject4$2(), getPadding, getPadding, function (p) {
  var sizes = Object.keys(p.theme.grid.sizes);
  var mediaQueries = sizes.filter(function (size) {
    return !!p[size];
  }).map(function (size) {
    return (// if smallest breakpoint no query needed
      size === lodash.head(sizes) ? styled.css(_templateObject5$1(), getColumnWidth(p[size], p.theme.grid.columns), p["".concat(size, "Offset")] && getOffset(p["".concat(size, "Offset")], p.theme.grid.columns)) : // all other breakpoints use a media query
      styled.css(_templateObject6(), p.theme.grid.sizes[size], getColumnWidth(p[size], p.theme.grid.columns), p["".concat(size, "Offset")] !== undefined && getOffset(p["".concat(size, "Offset")], p.theme.grid.columns))
    );
  });
  return styled.css(_templateObject7(), p.order ? p.order : 'initial', mediaQueries);
});

var Column = function Column(props) {
  return React__default.createElement(StyledColumn, props);
};

Column.propTypes = {
  /**
   * Margin between columns
   */
  gutter: PropTypes.number,

  /**
   * Collapse columns by removing gutters
   */
  collapse: PropTypes.bool
};
Column.defaultProps = {
  gutter: false,
  collapse: false
};

function _templateObject$9() {
  var data = _taggedTemplateLiteral(["\n  margin-left: auto;\n  margin-right: auto;\n  width: 100%;\n  max-width: ", ";\n  padding-left: ", "px;\n  padding-right: ", "px;\n"]);

  _templateObject$9 = function _templateObject() {
    return data;
  };

  return data;
}

var getPadding$1 = function getPadding(p) {
  return p.gutter ? p.gutter / 2 : p.theme.grid.gutter / 2;
};

var StyledContainer = createComponent({
  name: 'Container',
  as: Box
}).extend(_templateObject$9(), function (p) {
  return p.fluid ? '100%' : "".concat(p.maxWidth || p.theme.grid.containerMaxWidth, "px");
}, getPadding$1, getPadding$1);
StyledContainer.displayName = 'Container';

var Container = function Container(_ref) {
  var children = _ref.children,
      gutter = _ref.gutter,
      maxWidth = _ref.maxWidth,
      fluid = _ref.fluid;
  return React__default.createElement(StyledContainer, {
    fluid: fluid,
    gutter: gutter,
    maxWidth: maxWidth
  }, React__default.Children.map(children, function (child) {
    return React__default.cloneElement(child, {
      gutter: gutter
    });
  }));
};

Container.propTypes = {
  gutter: PropTypes.number
};

function _templateObject8() {
  var data = _taggedTemplateLiteral(["\n  background: #f9fafc;\n  padding: 12px;\n  border-radius: 0 0 7px 7px;\n  border-top: 1px solid #e9e9e9;\n  font-size: 14px;\n"]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$1() {
  var data = _taggedTemplateLiteral(["\n  opacity: ", ";\n  pointer-events: ", ";\n  text-decoration: none;\n  color: inherit;\n  display: flex;\n  align-items: center;\n  margin-left: -12px;\n  margin-right: -12px;\n  padding: 4px 12px;\n  font-size: 14px;\n  cursor: pointer;\n\n  & + ", " {\n    margin-top: 12px;\n  }\n\n  &:hover {\n    color: inherit;\n  }\n"]);

  _templateObject7$1 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$1() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  font-weight: 600;\n  font-size: 12px;\n  text-transform: uppercase;\n  color: ", ";\n  margin: 0 0 4px;\n"]);

  _templateObject6$1 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$2() {
  var data = _taggedTemplateLiteral(["\n  padding: 12px;\n"]);

  _templateObject5$2 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$3() {
  var data = _taggedTemplateLiteral(["\n  padding: 8px 12px;\n  background: ", ";\n  font-weight: bold;\n  font-size: 12px;\n  color: ", ";\n  text-transform: uppercase;\n"]);

  _templateObject4$3 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$5() {
  var data = _taggedTemplateLiteral(["\n  z-index: 10;\n  position: absolute;\n  left: 50%;\n  background: white;\n  border-radius: 2px;\n  opacity: 0;\n  visibility: hidden;\n  transform: translateX(-50%) scale(0.9);\n  transform-origin: 50% 0;\n  transition: all 300ms cubic-bezier(0.325, 0.09, 0, 1.28);\n  border: 1px solid #e4edf5;\n  box-shadow: 0 0 20px 0 rgba(178, 194, 212, 0.3);\n  min-width: 150px;\n  width: ", ";\n  ", ";\n"]);

  _templateObject3$5 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$6() {
  var data = _taggedTemplateLiteral(["\n  cursor: pointer;\n"]);

  _templateObject2$6 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$a() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  display: inline-block;\n"]);

  _templateObject$a = function _templateObject() {
    return data;
  };

  return data;
}
var OpenStyles = {
  bl: "\n    transform: scale(1);\n  ",
  b: "\n    transform: translateX(-50%) scale(1);\n  ",
  br: "\n    transform: scale(1);\n  ",
  tl: "\n    transform: scale(1);\n  ",
  t: "\n    transform: translateX(-50%) scale(1);\n  ",
  tr: "\n    transform: scale(1);\n  "
};
var PositionStyles = {
  bl: "\n    left: 0;\n    transform: translateX(0) scale(0.9);\n    transform-origin: 0 0;\n    top: calc(100% + 8px);\n  ",
  br: "\n    left: auto;\n    right: 0;\n    top: calc(100% + 8px);\n    transform: translateX(0) scale(0.9);\n    transform-origin: 100% 0;\n  ",
  tl: "\n    left: 0;\n    bottom: calc(100% + 8px);\n    transform: translateX(0) scale(0.9);\n    transform-origin: 0 0;\n  ",
  tr: "\n    left: auto;\n    right: 0;\n    bottom: calc(100% + 8px);\n    transform: translateX(0) scale(0.9);\n    transform-origin: 100% 0;\n  "
};

var getDropdownMenuStyles = function getDropdownMenuStyles(props) {
  return "\n  ".concat(PositionStyles[props.position], "\n  ").concat(props.open && "\n    opacity: 1;\n    visibility: visible;\n\n    ".concat(OpenStyles[props.position], ";\n  "), "\n");
};

var DropdownProvider = styled__default.div(_templateObject$a());
var DropdownTrigger = styled__default.div(_templateObject2$6());
var DropdownMenu = styled__default.div(_templateObject3$5(), function (p) {
  return "".concat(p.width || 150, "px");
}, getDropdownMenuStyles);

var Dropdown =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Dropdown, _React$Component);

  function Dropdown() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Dropdown);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Dropdown)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      isOpen: false
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "toggle", function () {
      if (_this.props.on !== 'click') return;

      if (_this.state.isOpen) {
        _this.close();
      } else {
        _this.open();
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "toggleHover", function () {
      if (_this.props.on !== 'hover') return;

      _this.setState({
        isOpen: !_this.state.isOpen
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "close", function () {
      _this.setState({
        isOpen: false
      }, _this.detachAutocloseListener);
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "open", function () {
      _this.setState({
        isOpen: true
      }, _this.attachAutocloseListener);
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "autoclose", function (e) {
      if (!_this.root || !_this.root.contains(e.target)) {
        _this.close();
      }
    });

    return _this;
  }

  _createClass(Dropdown, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        dropdown: {
          close: this.close.bind(this),
          open: this.open.bind(this)
        }
      };
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.detachAutocloseListener();
    }
  }, {
    key: "attachAutocloseListener",
    value: function attachAutocloseListener() {
      if (!this.props.autoclose) {
        return;
      }

      document.addEventListener('click', this.autoclose);
    }
  }, {
    key: "detachAutocloseListener",
    value: function detachAutocloseListener() {
      document.removeEventListener('click', this.autoclose);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          position = _this$props.position,
          width = _this$props.width,
          trigger = _this$props.trigger,
          render = _this$props.render;
      var isOpen = this.state.isOpen;
      return React__default.createElement(DropdownProvider, {
        innerRef: function innerRef(ref) {
          _this2.root = ref;
        }
      }, React__default.createElement(DropdownTrigger, {
        onFocus: this.toggleHover,
        onMouseOver: this.toggleHover,
        onMouseLeave: this.toggleHover,
        onClick: this.toggle,
        "aria-haspopup": "true",
        "aria-expanded": isOpen
      }, trigger), React__default.createElement(DropdownMenu, {
        open: isOpen,
        position: position,
        width: width
      }, render({
        close: this.close
      })));
    }
  }]);

  return Dropdown;
}(React__default.Component);

_defineProperty(Dropdown, "propTypes", {
  trigger: PropTypes.element,
  render: PropTypes.func,
  autoclose: PropTypes.bool,
  position: PropTypes.string,
  on: PropTypes.string
});

_defineProperty(Dropdown, "defaultProps", {
  autoclose: true,
  position: 'bl',
  on: 'click'
});

_defineProperty(Dropdown, "childContextTypes", {
  dropdown: PropTypes.object
});
Dropdown.Header = styled__default.div(_templateObject4$3(), function (p) {
  return p.theme.colors.grayLight;
}, function (p) {
  return p.theme.colors.grayMid;
});
Dropdown.Body = styled__default.div(_templateObject5$2());
Dropdown.Title = styled__default.h3(_templateObject6$1(), function (p) {
  return p.theme.colors.primary;
});
Dropdown.Item = styled__default.div(_templateObject7$1(), function (p) {
  return p.disabled ? 0.75 : 1;
}, function (p) {
  return p.disabled ? 'none' : 'initial';
}, Dropdown.Title);
Dropdown.Footer = styled__default.footer(_templateObject8());

function _templateObject$b() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  transition: 175ms;\n\n  & + & {\n    margin-top: 1rem;\n  }\n"]);

  _templateObject$b = function _templateObject() {
    return data;
  };

  return data;
}
var Field = createComponent({
  name: 'Field'
}).extend(_templateObject$b());

var VALIDATIONS = {
  required: function required(val) {
    if (!val || typeof val === 'string' && val === '') {
      throw new Error('This field is required');
    }
  },
  minLength: function minLength(val, _minLength) {
    if (!val || "".concat(val).length < _minLength) {
      throw new Error("This field must be longer than ".concat(_minLength, " characters"));
    }
  },
  maxLength: function maxLength(val, _maxLength) {
    if (val && "".concat(val).length > _maxLength) {
      throw new Error("This field cannot be less than ".concat(_maxLength, " characters"));
    }
  }
};

var Formbot =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Formbot, _React$Component);

  function Formbot() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Formbot);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Formbot)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      values: _this.props.initialValues || {},
      fields: {},
      errors: {}
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "reset", function () {
      _this.setState({
        values: {},
        fields: {},
        errors: {}
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "makeValidation", function (validation, value) {
      if (!validation.validator(value)) {
        throw new Error(validation.message || 'This field is required');
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onFocus", function (field) {
      _this.updateField(field, {
        focused: true
      }).then(function () {
        _this.props.onFocus(field);
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (field, value) {
      _this.updateField(field, {
        validated: false
      }).then(function () {
        _this.setState({
          values: _objectSpread({}, _this.state.values, _defineProperty({}, field, value))
        }, function () {
          _this.validateField(field);

          _this.props.onChange(field, value, _this.state.values);
        });
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onBlur", function (field) {
      _this.updateField(field, {
        blurred: true
      }).then(function () {
        return _this.validateField(field);
      }).then(function () {
        _this.props.onBlur(field);
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onSubmit", function (event) {
      event.preventDefault();

      _this.validateAllFields().then(function () {
        _this.props.onSubmit({
          isValid: _this.isValid,
          values: _this.state.values,
          errors: _this.state.errors
        });
      });
    });

    return _this;
  }

  _createClass(Formbot, [{
    key: "getValues",
    value: function getValues() {
      var _this2 = this;

      return this.validateAllFields().then(function () {
        return {
          isValid: _this2.isValid,
          values: _this2.values
        };
      });
    }
  }, {
    key: "setValues",
    value: function setValues() {
      var values = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.setState({
        values: _objectSpread({}, this.state.values, values)
      });
    }
  }, {
    key: "updateField",
    value: function updateField(field) {
      var _this3 = this;

      var updates = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      return new Promise(function (resolve) {
        var fieldState = _this3.state.fields[field] || {};

        _this3.setState({
          fields: _objectSpread({}, _this3.state.fields, _defineProperty({}, field, _objectSpread({}, fieldState, updates)))
        }, resolve);
      });
    }
  }, {
    key: "validateField",
    value: function validateField(field) {
      var _this4 = this;

      return new Promise(function (resolve) {
        var validation = _this4.props.validations[field];
        if (!validation) return;
        var fieldValue = _this4.state.values[field];
        var errorMsg;

        try {
          if (typeof validation === 'function') {
            validation(fieldValue);
          } else {
            Object.keys(validation).forEach(function (method) {
              var validator = VALIDATIONS[method];

              if (!validator) {
                throw new Error("Formbot: \"".concat(method, "\" is not a built-in validator."));
              }

              validator(fieldValue, validation[method]);
            });
          }
        } catch (err) {
          errorMsg = err.message;
        } finally {
          _this4.updateField(field, {
            validated: true
          }).then(function () {
            _this4.setState({
              errors: _objectSpread({}, _this4.state.errors, _defineProperty({}, field, errorMsg))
            }, resolve);
          });
        }
      });
    }
  }, {
    key: "validateAllFields",
    value: function validateAllFields() {
      var _this5 = this;

      return Promise.all(this.validatable.map(function (field) {
        return _this5.updateField(field, {}).then(function () {
          return _this5.validateField(field);
        });
      }));
    }
  }, {
    key: "render",
    value: function render() {
      return this.props.children(_objectSpread({}, this.props, {
        values: this.state.values,
        errors: this.state.errors,
        onChange: this.onChange,
        onFocus: this.onFocus,
        onBlur: this.onBlur,
        onSubmit: this.onSubmit,
        reset: this.reset
      }));
    }
  }, {
    key: "validatable",
    get: function get() {
      return Object.keys(this.props.validations);
    }
  }, {
    key: "isValid",
    get: function get() {
      return Object.values(this.state.errors).every(function (val) {
        return !val;
      });
    }
  }, {
    key: "values",
    get: function get() {
      return this.state.values;
    }
  }]);

  return Formbot;
}(React__default.Component);

_defineProperty(Formbot, "propTypes", {
  initialValues: PropTypes.shape(),
  validations: PropTypes.shape({
    fieldName: PropTypes.oneOfType([PropTypes.func, PropTypes.shape()])
  }),
  onFocus: PropTypes.func,
  onChange: PropTypes.func,
  onBlur: PropTypes.func,
  onSubmit: PropTypes.func
});

_defineProperty(Formbot, "defaultProps", {
  initialValues: {},
  validations: {},
  onFocus: function onFocus() {},
  onChange: function onChange() {},
  onBlur: function onBlur() {},
  onSubmit: function onSubmit() {}
});

var FormGroup = function FormGroup(_ref) {
  var children = _ref.children,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? 3 : _ref$padding;
  return React__default.createElement(Box, {
    mb: padding
  }, children);
};

function _templateObject2$7() {
  var data = _taggedTemplateLiteral(["\n      position: absolute;\n      top: 2px;\n      left: 8px;\n      opacity: ", ";\n      margin: 0;\n      font-size: ", "px;\n    "]);

  _templateObject2$7 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$c() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  transition: 250ms;\n  font-weight: 500;\n  margin: 0 0 4px 4px;\n  z-index: 10;\n  font-size: ", "px;\n\n  ", ";\n"]);

  _templateObject$c = function _templateObject() {
    return data;
  };

  return data;
}
var Label = createComponent({
  name: 'Label',
  tag: 'label'
}).extend(_templateObject$c(), function (p) {
  return p.theme.fontSizes[p.size];
}, function (props) {
  return props.isFloatable && styled.css(_templateObject2$7(), props.isFloating ? 1 : 0, props.theme.fontSizes[props.size] * 0.8);
});

function _templateObject4$4() {
  var data = _taggedTemplateLiteral(["\n        padding-bottom: 0;\n      "]);

  _templateObject4$4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$6() {
  var data = _taggedTemplateLiteral(["\n    border: 1px solid ", ";\n    height: ", "px;\n    display: block;\n    outline: none;\n    width: 100%;\n    padding: 8px;\n    border-radius: ", "px;\n    transition: 250ms all;\n    -webkit-appearance: none;\n    font-family: inherit;\n    font-size: ", "px;\n\n    &:hover,\n    &:focus,\n    &:active {\n      border-color: ", ";\n    }\n\n    ::placeholder {\n      color: ", ";\n    }\n\n    &[disabled] {\n      opacity: 0.65;\n    }\n\n    ", ";\n  "]);

  _templateObject3$6 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$8() {
  var data = _taggedTemplateLiteral(["\n  ", ";\n"]);

  _templateObject2$8 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$d() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n"]);

  _templateObject$d = function _templateObject() {
    return data;
  };

  return data;
}
var InputContainer = createComponent({
  name: 'InputContainer'
}).extend(_templateObject$d());
var StyledInput$1 = createComponent({
  name: 'Input',
  tag: 'input'
}).extend(_templateObject2$8(), function (_ref) {
  var isFloating = _ref.isFloating,
      size = _ref.size,
      theme = _ref.theme,
      _ref$borderRadius = _ref.borderRadius,
      borderRadius = _ref$borderRadius === void 0 ? theme.radius : _ref$borderRadius;
  return styled.css(_templateObject3$6(), theme.colors.grayLight, theme.heights[size], borderRadius, theme.fontSizes[size], theme.colors.grayMid, theme.colors.grayMid, isFloating && styled.css(_templateObject4$4()));
});
var StyledTextArea = StyledInput$1.withComponent('textarea');

var Input =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Input, _React$Component);

  function Input(props) {
    var _this;

    _classCallCheck(this, Input);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Input).call(this, props));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "getInput", function () {
      return _this.input;
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onFocus", function (e) {
      _this.setState({
        focused: true
      });

      _this.props.onFocus(e.target.name);
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onBlur", function (e) {
      _this.setState({
        focused: false
      });

      var _this$props = _this.props,
          onBlur = _this$props.onBlur,
          onChange = _this$props.onChange,
          transformOnBlur = _this$props.transformOnBlur;
      onBlur(e.target.name);
      var currentValue = _this.props.value;

      if (transformOnBlur && currentValue) {
        var transformedValue = transformOnBlur(currentValue);

        if (transformedValue !== currentValue) {
          onChange(e.target.name, transformedValue);
        }
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (e) {
      _this.autogrow();

      _this.setState({
        value: e.target.value
      });

      _this.props.onChange(e.target.name, e.target.value);
    });

    _this.input = React__default.createRef();
    _this.state = {
      value: props.value || '',
      focused: false
    };
    return _this;
  }

  _createClass(Input, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.autogrow) {
        this.createShadowElement();
        this.autogrow();
      }

      if (this.props.autofocus) {
        if (this.input.current) {
          this.input.current.focus();
        }
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(props) {
      if (props.value !== this.props.value) {
        this.setState({
          value: props.value
        });
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      if (prevProps.value !== this.props.value) {
        this.autogrow();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.shadow) {
        this.shadow.remove();
      }
    }
  }, {
    key: "createShadowElement",
    value: function createShadowElement() {
      this.shadow = document.createElement('textarea');
      this.shadow.style.position = 'absolute';
      this.shadow.style.left = '-9000px';
      document.body.appendChild(this.shadow);
    }
  }, {
    key: "autogrow",
    value: function autogrow() {
      var _this$props2 = this.props,
          multiline = _this$props2.multiline,
          autogrow = _this$props2.autogrow,
          minRows = _this$props2.minRows,
          maxRows = _this$props2.maxRows,
          rowHeight = _this$props2.rowHeight;

      if (!multiline || !autogrow) {
        return;
      }

      var minHeight = minRows * rowHeight;
      var maxHeight = maxRows * rowHeight;
      this.shadow.style.width = "".concat(this.input.clientWidth, "px");
      this.shadow.value = this.props.value || this.state.value;
      var height = this.shadow.scrollHeight + 14;

      if (height < minHeight) {
        height = minHeight;
      } else if (height > maxHeight) {
        height = maxHeight;
      }

      this.setState({
        height: height
      });
    }
  }, {
    key: "focus",
    value: function focus() {
      this.input.current.focus();
    }
  }, {
    key: "blur",
    value: function blur() {
      this.input.current.blur();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          className = _this$props3.className,
          style = _this$props3.style,
          minRows = _this$props3.minRows,
          maxRows = _this$props3.maxRows,
          rowHeight = _this$props3.rowHeight,
          label = _this$props3.label,
          multiline = _this$props3.multiline,
          autogrow = _this$props3.autogrow,
          autofocus = _this$props3.autofocus,
          id = _this$props3.id,
          error = _this$props3.error,
          value = _this$props3.value,
          floating = _this$props3.floating,
          placeholder = _this$props3.placeholder,
          transformOnBlur = _this$props3.transformOnBlur,
          size = _this$props3.size,
          rest = _objectWithoutProperties(_this$props3, ["className", "style", "minRows", "maxRows", "rowHeight", "label", "multiline", "autogrow", "autofocus", "id", "error", "value", "floating", "placeholder", "transformOnBlur", "size"]);

      var isFloating = floating && value && value.length > 0 || floating && this.state.value;

      var inputProps = _objectSpread({}, rest, {
        id: id,
        innerRef: this.input,
        size: size,
        value: this.state.value,
        onChange: this.onChange,
        onFocus: this.onFocus,
        onBlur: this.onBlur,
        style: autogrow ? _objectSpread({}, style, {
          height: this.state.height
        }) : style,
        placeholder: placeholder,
        isFloatable: floating,
        isFloating: isFloating
      });

      var Label$$1 = label ? React__default.createElement(Label, {
        htmlFor: id,
        styles: rest.styles,
        size: size,
        isFloatable: floating,
        isFloating: isFloating
      }, label) : null;
      return React__default.createElement(Field, {
        styles: rest.styles
      }, !floating && Label$$1, React__default.createElement(InputContainer, {
        styles: rest.styles
      }, floating && Label$$1, multiline ? React__default.createElement(StyledTextArea, inputProps) : React__default.createElement(StyledInput$1, inputProps)), !this.state.focused && error ? React__default.createElement(FormError, {
        styles: rest.styles
      }, error) : null);
    }
  }]);

  return Input;
}(React__default.Component);

_defineProperty(Input, "propTypes", {
  value: PropTypes.string,
  disabled: PropTypes.bool,
  placeholder: PropTypes.string,
  multiline: PropTypes.bool,
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  type: PropTypes.string,
  minRows: PropTypes.number,
  rows: PropTypes.number,
  maxRows: PropTypes.number,
  rowHeight: PropTypes.number,
  autogrow: PropTypes.bool,
  size: PropTypes.string,
  floating: PropTypes.bool
});

_defineProperty(Input, "defaultProps", {
  type: 'text',
  multiline: false,
  minRows: 2,
  rows: 3,
  maxRows: 6,
  rowHeight: 14 * 1.5,
  autogrow: false,
  disabled: false,
  size: 'md',
  onFocus: function onFocus() {},
  onBlur: function onBlur() {},
  onChange: function onChange() {},
  floating: false
});

function _templateObject$e() {
  var data = _taggedTemplateLiteral(["\n  a {\n    color: inherit;\n    text-decoration: underline;\n  }\n"]);

  _templateObject$e = function _templateObject() {
    return data;
  };

  return data;
}
var Container$1 = styled__default.span(_templateObject$e());
var REGEX = /(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/gi;

var parse = function parse(string) {
  return string.replace(REGEX, function (url) {
    return "<a target=\"_blank\" href=\"".concat(url, "\">").concat(url, "</a>");
  });
};

var Linkify = function Linkify(props) {
  return React__default.createElement(Container$1, {
    style: props.style || {},
    dangerouslySetInnerHTML: {
      __html: parse(props.children)
    }
  });
};

function _templateObject11() {
  var data = _taggedTemplateLiteral(["\n  padding: 0 24px 24px;\n"]);

  _templateObject11 = function _templateObject11() {
    return data;
  };

  return data;
}

function _templateObject10() {
  var data = _taggedTemplateLiteral(["\n  padding: 24px;\n"]);

  _templateObject10 = function _templateObject10() {
    return data;
  };

  return data;
}

function _templateObject9() {
  var data = _taggedTemplateLiteral(["\n  font-size: 20px;\n  font-weight: 600;\n  padding: 0 24px;\n  margin: 24px 0 0;\n"]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8$1() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  margin: auto;\n  min-width: ", "px;\n  max-width: ", "px;\n  background: #ffffff;\n  background-clip: padding-box;\n  box-shadow: 0 8px 30px rgba(0, 29, 54, 0.1);\n  border-radius: 2px;\n  ", " ", ";\n"]);

  _templateObject8$1 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$2() {
  var data = _taggedTemplateLiteral(["\n      animation: 0.35s ", ";\n    "]);

  _templateObject7$2 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$2() {
  var data = _taggedTemplateLiteral(["\n      animation: 0.35s ", ";\n    "]);

  _templateObject6$2 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$3() {
  var data = _taggedTemplateLiteral(["\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  z-index: 1000;\n  padding: 12px;\n  display: flex;\n  align-items: center;\n  position: fixed;\n  overflow-y: auto;\n  overflow-x: hidden;\n  background: rgba(0, 0, 0, 0.2);\n  justify-content: center;\n  ", ";\n  ", ";\n"]);

  _templateObject5$3 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$5() {
  var data = _taggedTemplateLiteral(["", ""]);

  _templateObject4$5 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$7() {
  var data = _taggedTemplateLiteral(["", ""]);

  _templateObject3$7 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$9() {
  var data = _taggedTemplateLiteral(["", ""]);

  _templateObject2$9 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$f() {
  var data = _taggedTemplateLiteral(["", ""]);

  _templateObject$f = function _templateObject() {
    return data;
  };

  return data;
}
var fadeInAnimation = styled.keyframes(_templateObject$f(), reactAnimations.fadeIn);
var fadeOutAnimation = styled.keyframes(_templateObject2$9(), reactAnimations.fadeOut);
var fadeInUpAnimation = styled.keyframes(_templateObject3$7(), reactAnimations.fadeInUp);
var fadeOutUpAnimation = styled.keyframes(_templateObject4$5(), reactAnimations.fadeOutUp);
var Backdrop = createComponent({
  name: 'ModalBackdrop'
}).extend(_templateObject5$3(), function (_ref) {
  var opening = _ref.opening;
  return opening && styled.css(_templateObject6$2(), fadeInAnimation);
}, function (_ref2) {
  var closing = _ref2.closing;
  return closing && styled.css(_templateObject7$2(), fadeOutAnimation);
});
var ModalContent = createComponent({
  name: 'ModalContent'
}).extend(_templateObject8$1(), function (p) {
  return p.minWidth || 250;
}, function (p) {
  return p.maxWidth || 768;
}, function (_ref3) {
  var opening = _ref3.opening;
  return opening && "animation: 0.75s ".concat(fadeInUpAnimation, ";");
}, function (_ref4) {
  var closing = _ref4.closing;
  return closing && "animation: 0.75s ".concat(fadeOutUpAnimation, ";");
});

var Modal =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Modal, _React$Component);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Modal).call(this, props));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleEscapeKey", function (event) {
      if (!_this.props.closeOnEscape) {
        return;
      }

      if (event.keyCode === 27) {
        _this.closeInternal();
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleBackdropClick", function () {
      if (!_this.props.closeOnBackdropClick) {
        return;
      }

      _this.closeInternal();
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleContentClick", function (event) {
      event.stopPropagation();
    });

    _this.state = {
      open: props.open || false,
      opening: false,
      closing: false
    };
    return _this;
  }

  _createClass(Modal, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(oldProps) {
      if (!oldProps.open && this.props.open) {
        this.open();
      } else if (oldProps.open && !this.props.open) {
        this.close();
      }
    }
  }, {
    key: "open",
    value: function open() {
      var _this2 = this;

      this.setState({
        opening: true
      }, function () {
        setTimeout(function () {
          document.addEventListener('keydown', _this2.handleEscapeKey);

          _this2.setState({
            open: true,
            opening: false
          });
        }, 250);
      });
    }
  }, {
    key: "close",
    value: function close() {
      var _this3 = this;

      this.setState({
        closing: true
      }, function () {
        setTimeout(function () {
          document.removeEventListener('keydown', _this3.handleEscapeKey);

          _this3.setState({
            open: false,
            closing: false
          });
        }, 250);
      });
    }
  }, {
    key: "closeInternal",
    value: function closeInternal() {
      if (this.isControlled) {
        this.props.onClose();
      } else {
        this.close();
      }
    }
  }, {
    key: "render",
    value: function render() {
      if (this.isClosed) {
        return null;
      }

      var _this$state = this.state,
          opening = _this$state.opening,
          closing = _this$state.closing;
      var _this$props = this.props,
          children = _this$props.children,
          minWidth = _this$props.minWidth,
          maxWidth = _this$props.maxWidth;
      return React__default.createElement(Backdrop, {
        opening: opening,
        closing: closing,
        onClick: this.handleBackdropClick
      }, React__default.createElement(ModalContent, {
        opening: opening,
        closing: closing,
        onClick: this.handleContentClick,
        minWidth: minWidth,
        maxWidth: maxWidth
      }, children));
    }
  }, {
    key: "isOpen",
    get: function get() {
      return !this.closed;
    }
  }, {
    key: "isClosed",
    get: function get() {
      var _this$state2 = this.state,
          open = _this$state2.open,
          opening = _this$state2.opening,
          closing = _this$state2.closing;
      return !open && !opening && !closing;
    }
  }, {
    key: "isControlled",
    get: function get() {
      return 'open' in this.props;
    }
  }]);

  return Modal;
}(React__default.Component);

_defineProperty(Modal, "propTypes", {
  open: PropTypes.bool,
  closeOnBackdropClick: PropTypes.bool,
  closeOnEscape: PropTypes.bool,
  onClose: PropTypes.func
});

_defineProperty(Modal, "defaultProps", {
  open: false,
  closeOnBackdropClick: true,
  closeOnEscape: true,
  onClose: function onClose() {}
});

Modal.Title = createComponent({
  name: 'ModalTitle',
  tag: 'h2'
}).extend(_templateObject9());
Modal.Body = createComponent({
  name: 'ModalBody'
}).extend(_templateObject10());
Modal.Footer = createComponent({
  name: 'ModalFooter'
}).extend(_templateObject11());

function _templateObject3$8() {
  var data = _taggedTemplateLiteral(["\n    height: ", "px;\n    width: ", "px;\n    border: ", "px solid ", ";\n  "]);

  _templateObject3$8 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$a() {
  var data = _taggedTemplateLiteral(["\n  ", ";\n\n  border-right-color: ", ";\n  border-radius: 50%;\n  animation: ", " 1.1s infinite linear;\n"]);

  _templateObject2$a = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$g() {
  var data = _taggedTemplateLiteral(["\n  from { transform: rotate(0deg); }\n  from { transform: rotate(360deg); }\n"]);

  _templateObject$g = function _templateObject() {
    return data;
  };

  return data;
}
var spin = styled.keyframes(_templateObject$g());
var Spinner = createComponent({
  name: 'Spinner'
}).extend(_templateObject2$a(), function (_ref) {
  var _ref$size = _ref.size,
      size = _ref$size === void 0 ? 15 : _ref$size;
  return styled.css(_templateObject3$8(), size, size, size / 10, function (p) {
    return polished.rgba(p.theme.colors.primary, 0.3);
  });
}, function (p) {
  return p.theme.colors.primary;
}, spin);

function _templateObject$h() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: column;\n  height: 100%;\n  width: 100%;\n  align-items: center;\n  justify-content: center;\n  min-height: 50px;\n"]);

  _templateObject$h = function _templateObject() {
    return data;
  };

  return data;
}
var Container$2 = createComponent({
  name: 'Placeholder'
}).extend(_templateObject$h());

var Loadable =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Loadable, _React$Component);

  function Loadable() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Loadable);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Loadable)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      delayed: false
    });

    return _this;
  }

  _createClass(Loadable, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.runDelay();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      clearTimeout(this.delayTimer);
    }
  }, {
    key: "runDelay",
    value: function runDelay() {
      var _this2 = this;

      if (this.props.delay <= 0) return;
      this.setState({
        delayed: true
      }, function () {
        _this2.delayTimer = setTimeout(function () {
          _this2.setState({
            delayed: false
          });
        }, _this2.props.delay);
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          loading = _this$props.loading,
          error = _this$props.error,
          renderLoading = _this$props.renderLoading,
          renderError = _this$props.renderError,
          onReload = _this$props.onReload;

      if (loading && this.state.delayed) {
        return null;
      }

      if (loading) {
        return renderLoading ? renderLoading() : React__default.createElement(Container$2, null, React__default.createElement(Spinner, null));
      }

      if (error) {
        return renderError ? renderError() : React__default.createElement(Container$2, {
          textAlign: "center"
        }, React__default.createElement("strong", null, "Oh no!"), React__default.createElement(Box, {
          mt: 1,
          mb: 2
        }, error), React__default.createElement(Button, {
          size: "xs",
          variant: "primary",
          outline: true,
          onClick: onReload
        }, "Try Again"));
      }

      return typeof children === 'function' ? children() : children;
    }
  }]);

  return Loadable;
}(React__default.Component);

_defineProperty(Loadable, "propTypes", {
  loading: PropTypes.bool,
  error: PropTypes.string,
  delay: PropTypes.number,
  renderLoading: PropTypes.func,
  renderError: PropTypes.func,
  onReload: PropTypes.func
});

_defineProperty(Loadable, "defaultProps", {
  loading: false,
  delay: 250
});

var StyledRadioGroup = createComponent({
  name: 'RadioGroup',
  as: Box
});

var RadioGroup =
/*#__PURE__*/
function (_Component) {
  _inherits(RadioGroup, _Component);

  function RadioGroup() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, RadioGroup);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(RadioGroup)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      value: _this.props.value || null
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleChange", function (field, value) {
      // Bail out if value is the same
      if (_this.state.value === value) return;

      _this.setState({
        value: value
      });

      _this.props.onChange(_this.props.name, value);
    });

    return _this;
  }

  _createClass(RadioGroup, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      if (this.props.value !== undefined && this.props.value !== this.state.value) {
        this.handleChange(null, this.props.value);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          choices = _this$props.choices,
          error = _this$props.error,
          horizontal = _this$props.horizontal,
          label = _this$props.label,
          name = _this$props.name,
          color = _this$props.color,
          size = _this$props.size;
      return React__default.createElement(StyledRadioGroup, null, label && React__default.createElement(Label, null, label), React__default.createElement(Flex, {
        flexDirection: horizontal ? 'row' : 'column'
      }, choices.length && choices.map(function (choice) {
        var _choice$value = choice.value,
            value = _choice$value === void 0 ? choice.id : _choice$value,
            choiceLabel = choice.label;
        var key = "RadioButton-".concat(name, "-").concat(value);
        return React__default.createElement(Checkbox, {
          id: key,
          key: key,
          name: key,
          horizontal: horizontal,
          size: size,
          color: color,
          label: choiceLabel,
          value: _this2.state.value,
          valueTrue: value,
          iconOn: "radiobox-marked",
          iconOff: "radiobox-blank",
          onChange: _this2.handleChange
        });
      })), !!error && React__default.createElement(FormError, null, error));
    }
  }]);

  return RadioGroup;
}(React.Component);

_defineProperty(RadioGroup, "propTypes", {
  name: PropTypes.string,
  onChange: PropTypes.func,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  color: PropTypes.string,
  size: PropTypes.string,
  choices: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    label: PropTypes.string,
    disabled: PropTypes.bool
  }))
});

_defineProperty(RadioGroup, "defaultProps", {
  choices: [],
  onChange: function onChange() {},
  color: 'primary',
  size: 'md'
});

function _templateObject2$b() {
  var data = _taggedTemplateLiteral(["\n      flex: 0 1 auto;\n      flex-direction: ", ";\n      flex-wrap: wrap;\n      margin-right: -", "px;\n      margin-left: -", "px;\n    "]);

  _templateObject2$b = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$i() {
  var data = _taggedTemplateLiteral(["\n  ", "\n"]);

  _templateObject$i = function _templateObject() {
    return data;
  };

  return data;
}

var getMargin = function getMargin(p) {
  if (p.collapse) return 0;
  return p.gutter ? p.gutter / 2 : p.theme.grid.gutter / 2;
};

var StyledRow = createComponent({
  name: 'Row',
  as: Flex
}).extend(_templateObject$i(), function (p) {
  var direction = p.vertical ? 'column' : 'row';
  return styled.css(_templateObject2$b(), p.reverse ? "".concat(direction, "-reverse") : direction, getMargin, getMargin);
});

var Row = function Row(_ref) {
  var children = _ref.children,
      gutter = _ref.gutter,
      reverse = _ref.reverse,
      collapse = _ref.collapse,
      vertical = _ref.vertical,
      props = _objectWithoutProperties(_ref, ["children", "gutter", "reverse", "collapse", "vertical"]);

  return React__default.createElement(StyledRow, _extends({}, props, {
    gutter: gutter,
    reverse: reverse,
    collapse: collapse,
    vertical: vertical
  }), React__default.Children.map(children, function (child) {
    return React__default.cloneElement(child, {
      gutter: gutter,
      collapse: collapse,
      vertical: vertical
    });
  }));
};

Row.displayName = 'Row';
Row.propTypes = {
  /**
   * Lay row out vertically
   */
  vertical: PropTypes.bool,

  /**
   * Margin between columns
   */
  gutter: PropTypes.number,

  /**
   *  Reverse the order of the columns
   */
  reverse: PropTypes.bool,

  /**
   * Collapse columns by removing gutters
   */
  collapse: PropTypes.bool
};
Row.defaultProps = {
  vertical: false,
  reverse: false,
  collapse: false
};

function _templateObject4$6() {
  var data = _taggedTemplateLiteral(["\n  position: absolute;\n  height: 100%;\n  right: 0;\n  top: 0;\n  z-index: 1;\n"]);

  _templateObject4$6 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$9() {
  var data = _taggedTemplateLiteral(["\n        color: ", ";\n        select {\n          color: ", ";\n        }\n      "]);

  _templateObject3$9 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$c() {
  var data = _taggedTemplateLiteral(["\n    background: white;\n    border: 1px solid ", ";\n    height: ", "px;\n    outline: none;\n    width: 100%;\n    padding: 0.5rem;\n    position: relative;\n    border-radius: ", "px;\n    transition: 250ms all;\n    -webkit-appearance: none;\n    font-family: inherit;\n    font-size: ", "px;\n    vertical-align: middle;\n\n    ", ";\n\n    select {\n      position: relative;\n      z-index: 2;\n      outline: none;\n      width: 100%;\n      font-size: ", "px;\n      background: transparent;\n      border: none;\n      -webkit-appearance: none;\n    }\n  "]);

  _templateObject2$c = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$j() {
  var data = _taggedTemplateLiteral(["\n  ", "\n"]);

  _templateObject$j = function _templateObject() {
    return data;
  };

  return data;
}
var SelectContain = createComponent({
  name: 'Select',
  as: Flex
}).extend(_templateObject$j(), function (_ref) {
  var size = _ref.size,
      theme = _ref.theme,
      _ref$borderRadius = _ref.borderRadius,
      borderRadius = _ref$borderRadius === void 0 ? theme.radius : _ref$borderRadius;
  return styled.css(_templateObject2$c(), theme.colors.grayLight, theme.heights[size], borderRadius, theme.fontSizes[size], function (props) {
    return !props.value && styled.css(_templateObject3$9(), function (p) {
      return p.theme.colors.grayMid;
    }, function (p) {
      return p.theme.colors.grayMid;
    });
  }, function (p) {
    return p.theme.fontSizes[p.size];
  });
});
var IconContain = styled__default(Flex)(_templateObject4$6());

function Select(_ref2) {
  var id = _ref2.id,
      _ref2$name = _ref2.name,
      name = _ref2$name === void 0 ? id : _ref2$name,
      options = _ref2.options,
      placeholder = _ref2.placeholder,
      value = _ref2.value,
      error = _ref2.error,
      _onChange = _ref2.onChange,
      _onBlur = _ref2.onBlur,
      _ref2$size = _ref2.size,
      size = _ref2$size === void 0 ? 'md' : _ref2$size,
      label = _ref2.label;
  return React__default.createElement(Field, null, label && React__default.createElement(Label, {
    size: size
  }, label), React__default.createElement(SelectContain, {
    value: value,
    size: size
  }, React__default.createElement("select", {
    name: name,
    id: id,
    value: value,
    onChange: function onChange(e) {
      if (typeof _onChange === 'function') _onChange(name, e.target.value);
    },
    onBlur: function onBlur(e) {
      if (typeof _onBlur === 'function') _onBlur(name, e.target.value);
    }
  }, React__default.createElement("option", {
    value: ""
  }, placeholder || 'Select an option...'), options.map(function (option) {
    return React__default.createElement("option", {
      key: option.value,
      value: option.value
    }, option.label);
  })), React__default.createElement(IconContain, {
    mr: 2,
    alignItems: "center",
    justifyContent: "center"
  }, React__default.createElement(Icon, {
    name: "chevron-down",
    size: 18
  }))), error && React__default.createElement(FormError, null, error));
}

Select.propTypes = {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  options: PropTypes.array.isRequired,
  placeholder: PropTypes.string,
  value: PropTypes.string,
  error: PropTypes.string,
  onChange: PropTypes.func,
  onBlur: PropTypes.func,
  size: PropTypes.string,
  label: PropTypes.string
};

function _templateObject5$4() {
  var data = _taggedTemplateLiteral(["\n          transform: translateX(", "px);\n        "]);

  _templateObject5$4 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$7() {
  var data = _taggedTemplateLiteral(["\n    border-radius: 34px;\n    position: absolute;\n    cursor: pointer;\n    top: 0;\n    left: 0;\n    right: 0;\n    bottom: 0;\n    transition: 0.3s;\n    background-color: ", ";\n\n    &:before {\n      border-radius: 100%;\n      position: absolute;\n      content: '';\n      height: ", "px;\n      width: ", "px;\n      left: ", "px;\n      bottom: ", "px;\n      background-color: white;\n      transition: 0.3s;\n      ", ";\n    }\n  "]);

  _templateObject4$7 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$a() {
  var data = _taggedTemplateLiteral(["\n  ", ";\n"]);

  _templateObject3$a = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$d() {
  var data = _taggedTemplateLiteral(["\n  display: none;\n"]);

  _templateObject2$d = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$k() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  display: inline-block;\n  width: ", "px;\n  height: ", "px;\n"]);

  _templateObject$k = function _templateObject() {
    return data;
  };

  return data;
}
var SwitchContain = styled__default.label(_templateObject$k(), function (p) {
  return p.size * 2;
}, function (p) {
  return p.size + p.inset;
});
var SwitchInput = styled__default.input(_templateObject2$d());
var SwitchThumb = styled__default.span(_templateObject3$a(), function (_ref) {
  var variant = _ref.variant,
      size = _ref.size,
      inset = _ref.inset,
      on = _ref.on,
      theme = _ref.theme,
      _ref$backgroundColor = _ref.backgroundColor,
      backgroundColor = _ref$backgroundColor === void 0 ? theme.colors[variant] || theme.colors[theme.variants[variant]] : _ref$backgroundColor;
  return styled.css(_templateObject4$7(), on ? backgroundColor : theme.colors.grayMid, size, size, inset / 2, inset / 2, on && styled.css(_templateObject5$4(), size - inset));
});

var Switch =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Switch, _React$Component);

  function Switch() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Switch);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Switch)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      on: _this.props.value || false
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleChange", function () {
      var _this$props = _this.props,
          onChange = _this$props.onChange,
          name = _this$props.name;
      var on = _this.state.on;

      _this.setState({
        on: !on
      }, function () {
        // only pass an update if onChange is defined
        if (typeof onChange === 'function') {
          _this.props.onChange(name, _this.state.on);
        }
      });
    });

    return _this;
  }

  _createClass(Switch, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      // update switch state based on props passed in
      if ('value' in this.props) {
        if (this.props.value !== this.state.on && this.props.value !== prevProps.value) {
          this.update(this.props);
        }
      }
    }
  }, {
    key: "update",
    value: function update(newProps) {
      this.setState({
        on: newProps.value
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          id = _this$props2.id,
          name = _this$props2.name,
          size = _this$props2.size,
          variant = _this$props2.variant,
          inset = _this$props2.inset;
      var on = this.state.on;
      return React__default.createElement(SwitchContain, {
        size: size,
        inset: inset
      }, React__default.createElement(SwitchInput, {
        id: id,
        name: name,
        type: "checkbox",
        on: on,
        onChange: this.handleChange
      }), React__default.createElement(SwitchThumb, {
        variant: variant,
        size: size,
        on: on,
        inset: inset
      }));
    }
  }]);

  return Switch;
}(React__default.Component);

_defineProperty(Switch, "propTypes", {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  value: PropTypes.bool,
  size: PropTypes.number,
  inset: PropTypes.number,
  variant: PropTypes.string
});

_defineProperty(Switch, "defaultProps", {
  variant: 'primary',
  size: 16,
  inset: 8
});

function _templateObject7$3() {
  var data = _taggedTemplateLiteral(["\n  width: 100%;\n"]);

  _templateObject7$3 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$3() {
  var data = _taggedTemplateLiteral(["\n  color: ", ";\n  display: block;\n  padding: ", ";\n  border-", ": 4px solid ", ";\n\n  &::hover {\n    color: #212b36;\n    border-color: ", ";\n  }\n"]);

  _templateObject6$3 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$5() {
  var data = _taggedTemplateLiteral(["\n  appearance: none;\n  margin: 0;\n  padding: 0;\n  background: none;\n  border: none;\n  font-size: 14px;\n  font-family: inherit;\n  position: relative;\n  justify-content: center;\n  cursor: pointer;\n  margin-", ": 1px;\n  margin-", ": -1px;\n  padding: ", ";\n  outline: none;\n  white-space: nowrap;\n  opacity: ", ";\n\n  &:active {\n    outline: none;\n  }\n"]);

  _templateObject5$5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$8() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  margin: 0;\n  padding: 0;\n"]);

  _templateObject4$8 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$b() {
  var data = _taggedTemplateLiteral(["\n      border-bottom: 1px solid #dfe3e8;\n    "]);

  _templateObject3$b = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$e() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  margin: 0;\n  padding: 0;\n  list-style: none;\n  flex-direction: ", ";\n  ", ";\n"]);

  _templateObject2$e = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$l() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: ", ";\n"]);

  _templateObject$l = function _templateObject() {
    return data;
  };

  return data;
}
var TabsProvider = createComponent({
  name: 'Tabs'
}).extend(_templateObject$l(), function (p) {
  return p.vertical ? 'row' : 'column';
});
var TabList = createComponent({
  name: 'TabList',
  tag: 'ul'
}).extend(_templateObject2$e(), function (p) {
  return p.vertical ? 'column' : 'row';
}, function (p) {
  return !p.vertical && styled.css(_templateObject3$b());
});
var TabListItem = createComponent({
  name: 'TabListItem',
  tag: 'li'
}).extend(_templateObject4$8());
var Tab = createComponent({
  name: 'Tab',
  tag: 'button'
}).extend(_templateObject5$5(), function (p) {
  return p.vertical ? 'left' : 'top';
}, function (p) {
  return p.vertical ? 'right' : 'bottom';
}, function (p) {
  return p.vertical ? '0' : '0 12px';
}, function (p) {
  return p.disabled ? 0.5 : 1;
});
var TabTitle = createComponent({
  name: 'TabTitle',
  tag: 'span'
}).extend(_templateObject6$3(), function (p) {
  return p.active ? '#212b36' : '#637381';
}, function (p) {
  return p.vertical ? '8px 12px 8px 8px' : '12px 8px';
}, function (p) {
  return p.vertical ? 'left' : 'bottom';
}, function (p) {
  return p.active ? p.theme.colors.primary : 'transparent';
}, function (p) {
  return p.active ? p.theme.colors.primary : '#d9dee3';
});
var TabContent = createComponent({
  name: 'TabContent',
  tag: 'div'
}).extend(_templateObject7$3());

var Tabs =
/*#__PURE__*/
function (_Component) {
  _inherits(Tabs, _Component);

  function Tabs() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Tabs);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Tabs)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      active: _this.props.active || 0
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleTabClick", function (selected) {
      if (_this.props.onChange) {
        _this.props.onChange(selected);
      }

      _this.setState({
        active: selected
      });
    });

    return _this;
  }

  _createClass(Tabs, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      if (this.props.active && this.props.active !== this.state.active) {
        this.setState({
          active: this.props.active
        });
      }
    }
  }, {
    key: "renderHeadings",
    value: function renderHeadings() {
      var _this2 = this;

      return this.props.tabs.map(function (tab, i) {
        var id = tab.id || i;
        return React__default.createElement(TabListItem, {
          key: id
        }, React__default.createElement(Tab, {
          id: id,
          disabled: tab.disabled,
          vertical: _this2.props.vertical,
          onClick: function onClick() {
            if (tab.onActive) {
              tab.onActive();
            }

            _this2.handleTabClick(i);
          }
        }, React__default.createElement(TabTitle, {
          active: _this2.state.active === i,
          vertical: _this2.props.vertical
        }, tab.title)));
      });
    }
  }, {
    key: "renderContent",
    value: function renderContent() {
      var content = this.props.tabs[this.state.active].content;

      if (React__default.isValidElement(content)) {
        return content;
      }

      throw new Error('Tab content must be a valid React element.');
    }
  }, {
    key: "render",
    value: function render() {
      return React__default.createElement(TabsProvider, {
        vertical: this.props.vertical
      }, React__default.createElement(TabList, {
        vertical: this.props.vertical
      }, this.renderHeadings()), React__default.createElement(TabContent, null, this.renderContent()));
    }
  }]);

  return Tabs;
}(React.Component);

_defineProperty(Tabs, "propTypes", {
  tabs: PropTypes.arrayOf(PropTypes.shape()).isRequired,
  active: PropTypes.number,
  vertical: PropTypes.bool,
  onChange: PropTypes.func
});

_defineProperty(Tabs, "defaultProps", {
  vertical: false
});

var defaultTheme = (function () {
  var overrides = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var colors = lodash.merge({
    primary: '#5759D6',
    grayLightest: '#f1f5f9',
    grayLight: '#cfd7df',
    grayMid: '#8297a4',
    grayDark: '#576574',
    red: '#c0392b',
    blue: '#2980b9',
    green: '#27ae60',
    orange: '#e67e22'
  }, overrides.colors);
  var radii = [0, 2, 4];
  var typography = {
    fontSize: 12
  };
  var variants = {
    primary: {
      backgroundColor: polished.lighten(0.325, colors.primary),
      fontColor: colors.primary
    },
    success: {
      backgroundColor: polished.lighten(0.45, colors.green),
      fontColor: colors.green
    },
    danger: {
      backgroundColor: polished.lighten(0.45, colors.red),
      fontColor: colors.red
    },
    warning: {
      backgroundColor: polished.lighten(0.45, colors.orange),
      fontColor: colors.orange
    },
    info: {
      backgroundColor: polished.lighten(0.45, colors.blue),
      fontColor: colors.blue
    },
    inverted: {
      backgroundColor: colors.primary,
      fontColor: 'white'
    },
    gray: {
      backgroundColor: polished.lighten(0.35, colors.grayMid),
      fontColor: colors.grayMid
    }
  };
  var heights = {
    xs: 28,
    sm: 32,
    md: 36,
    lg: 40,
    xl: 44
  };
  var fontSizes = {
    xs: 8,
    sm: 10,
    md: 12,
    lg: 14,
    xl: 16
  };
  var breakpoints = [368, 768, 1024, 1440];
  var grid = {
    containerMaxWidth: 1000,
    gutter: 16,
    columns: 12,
    sizes: {
      xs: breakpoints[0],
      sm: breakpoints[1],
      md: breakpoints[2],
      lg: breakpoints[3]
    }
  };
  return {
    classPrefix: 're',
    colors: colors,
    radius: 2,
    radii: radii,
    typography: typography,
    variants: variants,
    heights: heights,
    fontSizes: fontSizes,
    breakpoints: breakpoints,
    grid: grid
  };
});

var ThemeProvider = function ThemeProvider(props) {
  var theme = lodash.merge(defaultTheme(props.theme), props.theme);
  return React__default.createElement(styled.ThemeProvider, {
    theme: theme
  }, props.children);
};

exports.Alert = Alert;
exports.Box = Box;
exports.Button = Button;
exports.Card = Card;
exports.Checkbox = Checkbox;
exports.CheckboxGroup = CheckboxGroup;
exports.Column = Column;
exports.Container = Container;
exports.Dropdown = Dropdown;
exports.Field = Field;
exports.Flex = Flex;
exports.Formbot = Formbot;
exports.FormError = FormError;
exports.FormGroup = FormGroup;
exports.Icon = Icon;
exports.Input = Input;
exports.Label = Label;
exports.Linkify = Linkify;
exports.Modal = Modal;
exports.Placeholder = Loadable;
exports.RadioGroup = RadioGroup;
exports.Row = Row;
exports.Select = Select;
exports.Spinner = Spinner;
exports.Swtich = Switch;
exports.Tabs = Tabs;
exports.ThemeProvider = ThemeProvider;
